@@ -9,24 +9,28 @@ app = CLI("Interact with Tabletop Simulator mods")
 
 @app.command("unpack", help="Unpack a tts mod.")
 @app.argument(
-    "savegame", type=Path,
+    "savegame",
+    type=Path,
 )
-def unpack(options):
-    from .unpack import unpack
+def unpack_cmd(*, savegame: Path) -> None:
     from .config import config
+    from .unpack import unpack
 
-    unpack(savegame=options["savegame"], config=config)
+    unpack(savegame=savegame, config=config)
 
 
 @app.command("repack", help="Repack a tts mod.")
 @app.argument(
-    "savegame", type=Path, nargs="?", default="build/savegame.json",
+    "savegame",
+    type=Path,
+    nargs="?",
+    default="build/savegame.json",
 )
-def repack(options):
-    from .repack import repack
+def repack_cmd(*, savegame: Path) -> None:
     from .config import config
+    from .repack import repack
 
-    repack(savegame=options["savegame"], config=config)
+    repack(savegame=savegame, config=config)
 
 
 main = app.main
